# CTR_Function

![image](https://img.shields.io/badge/author-TIXhjq-orange)
![image](https://img.shields.io/badge/tensorflow-v2.1-darkgreen)
![image](https://img.shields.io/badge/pandas-v0.25.0-darkgreen)
![image](https://img.shields.io/badge/pypi_package-v0.0.1-lightgrey)
![image](https://img.shields.io/badge/License-Apache_2.0-blue)  
Email:hjq1922451756@gmail.com

    食用方式:
        pip install Data-Function  
        from kon. ...

>1.[code folder](https://github.com/TIXhjq/CTR_Function/tree/master/code)=[nn,feature_eng]
> 
>>1)新鲜,可食用  
>>>[CTR](https://github.com/TIXhjq/CTR_Function/tree/master/kon/model/ctr_model)  
>
>>2)需要重构部分(历史代码)  
>>>[Graph(重构)](https://github.com/TIXhjq/CTR_Function/tree/master/kon/model/embedding)  
>>>[Feature Enginner(重构)](https://github.com/TIXhjq/CTR_Function/tree/master/kon/model/feature_eng)  
>
>2.[paper](https://github.com/TIXhjq/CTR_Function/tree/master/paper)=[nn(目前只有CTR部分,剩下的下次一定^_^)]  
>3.[use example](https://github.com/TIXhjq/CTR_Function/tree/master/example)[ctr_example(充足),else(maybe...)]  
>4.[data](https://github.com/TIXhjq/CTR_Function/tree/master/data)=[nn test sample data]  
  
  p.s 每层目录有对应的详细介绍...
  
  [部分nn模型小结,不过比较懒,就几个就是了](https://zhuanlan.zhihu.com/c_1145034612807028736)  
  